Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(676)

Unified Diff: ash/wm/workspace/workspace.cc

Issue 16093036: Do not create a workspace for a maximized window. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: fix test failure Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/wm/workspace/workspace.h ('k') | ash/wm/workspace/workspace_layout_manager.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/wm/workspace/workspace.cc
diff --git a/ash/wm/workspace/workspace.cc b/ash/wm/workspace/workspace.cc
index 03e5004a073b04118e313e2b491f4a5206b56771..cd790a1a374e9f1cac27196e211ffa1b4e8d7dc1 100644
--- a/ash/wm/workspace/workspace.cc
+++ b/ash/wm/workspace/workspace.cc
@@ -20,8 +20,8 @@ namespace internal {
Workspace::Workspace(WorkspaceManager* manager,
aura::Window* parent,
- bool is_maximized)
- : is_maximized_(is_maximized),
+ bool is_fullscreen)
+ : is_fullscreen_(is_fullscreen),
workspace_manager_(manager),
window_(new aura::Window(NULL)),
event_handler_(new WorkspaceEventHandler(window_)),
@@ -72,7 +72,7 @@ aura::Window* Workspace::ReleaseWindow() {
}
bool Workspace::ShouldMoveToPending() const {
- if (!is_maximized_)
+ if (!is_fullscreen_)
return false;
for (size_t i = 0; i < window_->children().size(); ++i) {
@@ -80,8 +80,8 @@ bool Workspace::ShouldMoveToPending() const {
if (!child->TargetVisibility() || wm::IsWindowMinimized(child))
continue;
- // If we have a maximized window don't move to pending.
- if (WorkspaceManager::IsMaximized(child))
+ // If we have a fullscreen window don't move to pending.
+ if (wm::IsWindowFullscreen(child))
return false;
if (GetTrackedByWorkspace(child) && !GetPersistsAcrossAllWorkspaces(child))
@@ -90,13 +90,13 @@ bool Workspace::ShouldMoveToPending() const {
return true;
}
-int Workspace::GetNumMaximizedWindows() const {
+int Workspace::GetNumFullscreenWindows() const {
int count = 0;
for (size_t i = 0; i < window_->children().size(); ++i) {
aura::Window* child = window_->children()[i];
if (GetTrackedByWorkspace(child) &&
- (WorkspaceManager::IsMaximized(child) ||
- WorkspaceManager::WillRestoreMaximized(child))) {
+ (wm::IsWindowFullscreen(child) ||
+ WorkspaceManager::WillRestoreToWorkspace(child))) {
if (++count == 2)
return count;
}
« no previous file with comments | « ash/wm/workspace/workspace.h ('k') | ash/wm/workspace/workspace_layout_manager.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698